#!/usr/bin/python
# -*- coding: utf-8 -*-
# @Author : SandQuant
# @Email: data@sandquant.com

__title__ = 'SandInvest'
__description__ = 'SandInvest是一款专注于量化开发的金融数据接口，开始体验吧！'
__version__ = '0.5.0'
__author__ = 'SandQuant'
__author_email__ = 'data@sandquant.com'
__copyright__ = 'Copyright 2020-2022 SandQuant'
